{% load i18n %}

<div class="goscale-plugins-calendar">
	<dl class="ContentList">
		<dt>
			<span>
				{{ post.title|safe }}
			</span>
			<div class="EntryDate">{{ post.when }}</div>
		</dt>
		<dd>
			<div class="ContentListDescription">
                {% if event.description %}
                    <div>{{ event.description|safe }}</div>
                {% endif %}
				{% if post.where %}
					<div class="location-details">
						<span class="LocationLabel">{% trans "Location" %}: </span>{{ post.where }}<span class="mapLinkPlaceholder"> | <span class="error">{% trans "Sorry, this location cannot be found" %}</span><span class="ContentDetailLink"><span class="ContentDetailLinkLabel" data-title="{{ post.title|safe }}" data-where="{{ post.where }}" data-when="{{ post.when }}">{% trans "View map" %}</span><a class="link"></a></span></span>
					</div>
				{% endif %}
			</div>
		</dd>
	</dl>
</div>