{% load i18n %}

<div class="goscale-plugins-feeds post">
	<dl class="ContentList">
		<dt>
			<span>
				{{ post.title }}
			</span>
			<div class="EntryDate">{{ post.published|timesince }} {% trans "ago" %}</div>
		</dt>
		<dd>
			<div class="ContentListDescription">
				{{ post.description|safe }}
			</div>
		</dd>

		{% if disqus %}
			<div id="disqus_thread" data-shortname="{{ disqus }}"></div>
			<noscript>Please enable JavaScript to view the <a href="http://disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
			<a href="http://disqus.com" class="dsq-brlink">comments powered by <span class="logo-disqus">Disqus</span></a>
			<script type="text/javascript" src="{{ STATIC_URL }}goscale/js/disqus.js"></script>
		{% endif %}
	</dl>
</div>	