{% load i18n %}
{% load sekizai_tags %}
{% load goscale_tags %}

{% goscale_addtoblock "css" %}
	<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}goscale/css/goscale.plugins.form.css" />
{% endaddtoblock %}

{% goscale_addtoblock "js" %}
	<script type="text/javascript" src="{{ STATIC_URL }}goscale/js/goscale.plugins.form.js" data-callback="plugins.goscalePluginsForm"></script>
{% endaddtoblock %}

{% block posts_content %}
	{% if title %}
		<h1 class="form-title">{{ title }}</h1>
	{% endif %}
	<div class="goscale-plugins-form content" data-pluginjs="{{ STATIC_URL }}goscale/js/goscale.plugins.form.js" data-plugincb="goscalePluginsForm">
		{% if posts %}
			<form action="{{ posts.0.link }}" method="POST" class="ss-form" target="_blank">
				{% csrf_token %}
				<input type="hidden" name="url" value="{{ posts.0.link }}" />
				{{ posts.0.description|safe }}
			</form>
		{% endif %}
	</div>
{% endblock %}