.goscale-plugins-form {
	
}
	.goscale-plugins-form .ss-form-heading, .goscale-plugins-form .ss-footer,
	#form-lb .ss-form-heading, #form-lb .ss-footer {
		display: none;
	}
	.goscale-plugins-form .ss-resp-card, #form-lb .ss-resp-card {
		font-weight: bold;
	}
		.goscale-plugins-form .ss-resp-card .ss-confirmation, .goscale-plugins-form .ss-resp-card .ss-break,
		#form-lb .ss-resp-card .ss-confirmation, #form-lb .ss-resp-card .ss-break {
			display: none;
		}


/* form button style */
#form-buttons {
	position: fixed;
	top: 0;
	right: -50%;
	width: 100%;
	-webkit-transform: rotate(270deg);
    -webkit-transform-origin: bottom;
    -moz-transform: rotate(270deg);
    -moz-transform-origin: bottom;
    -o-transform: rotate(270deg);
    -o-transform-origin: bottom;
    -ms-transform: rotate(270deg);
    -ms-transform-origin: bottom;
    transform: rotate(270deg);
    transform-origin: bottom;
	writing-mode: bt-rl;
	text-align: center;
}
	#form-buttons .goscale-plugins-form {
		display: inline-block;
	}
		#form-buttons .form-button {
			display: inline-block;
			margin: 0 1px;
		}
			#form-buttons .form-button a {
				padding: 10px;
				text-transform: uppercase;
				font-size: 110%;
				background: #ccc;
				color: #fff;
				font-weight: bold;
				letter-spacing: 1px;
				text-decoration: none;
				display: inline-block;
				cursor: pointer;
			}
.form-lb-container {
	display: none;
}
.form-lb {
	/*width: 800px;
	height: 600px;*/
}
#fancybox-error {
	display: none;
}


/* IE fixes */
body.ie #form-buttons {
	right: 0;
	height: 100%;
	width: auto;
	-ms-transform: none;
}
body.ie #form-lb {
	*width: 530px;
}
body.ie #sideBar .box-sidebar .boxcontent .boxbottom {
	*float: left;
}